pub struct FetchConfig {
pub chunk_size: usize,
pub strategy: ConcurrencyStrategy,
}Fields
chunk_size: usizestrategy: ConcurrencyStrategyImplementations
Sourceimpl FetchConfig
impl FetchConfig
Sourcepub fn random_access() -> Self
pub fn random_access() -> Self
Use for cloud-based file formats that are randomly accessible, i.e. individual row groups (or record batches) and/or individual columns can be fetched directly using the metadata as an input. Example: Parquet, IPC with internal extensions.
The chunk_size should be small enough to enable smooth operation of the bytes-based in-flight concurrency controller.