AmazonS3ConfigKey

Enum AmazonS3ConfigKey 

#[non_exhaustive]
pub enum AmazonS3ConfigKey {
Show 28 variants AccessKeyId, SecretAccessKey, Region, DefaultRegion, Bucket, Endpoint, S3Endpoint, Token, ImdsV1Fallback, VirtualHostedStyleRequest, UnsignedPayload, Checksum, MetadataEndpoint, ContainerCredentialsRelativeUri, ContainerCredentialsFullUri, ContainerAuthorizationTokenFile, WebIdentityTokenFile, RoleArn, RoleSessionName, StsEndpoint, CopyIfNotExists, ConditionalPut, SkipSignature, DisableTagging, S3Express, RequestPayer, Client(ClientConfigKey), Encryption(S3EncryptionConfigKey),
}
Available on crate feature aws only.
Configuration keys for [AmazonS3Builder]

Configuration via keys can be done via [AmazonS3Builder::with_config]

Example

let builder = AmazonS3Builder::new()
    .with_config("aws_access_key_id".parse().unwrap(), "my-access-key-id")
    .with_config(AmazonS3ConfigKey::DefaultRegion, "my-default-region");

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AccessKeyId

AWS Access Key

See [AmazonS3Builder::with_access_key_id] for details.

Supported keys:

  • aws_access_key_id
  • access_key_id


SecretAccessKey

Secret Access Key

See [AmazonS3Builder::with_secret_access_key] for details.

Supported keys:

  • aws_secret_access_key
  • secret_access_key


Region

Region

See [AmazonS3Builder::with_region] for details.

Supported keys:

  • aws_region
  • region


DefaultRegion

Default region

See [AmazonS3Builder::with_region] for details.

Supported keys:

  • aws_default_region
  • default_region


Bucket

Bucket name

See [AmazonS3Builder::with_bucket_name] for details.

Supported keys:

  • aws_bucket
  • aws_bucket_name
  • bucket
  • bucket_name


Endpoint

Sets custom endpoint for communicating with AWS S3.

See [AmazonS3Builder::with_endpoint] for details.

Supported keys:

  • aws_endpoint
  • aws_endpoint_url
  • endpoint
  • endpoint_url


S3Endpoint

Service-specific S3 endpoint URL

When set, takes precedence over Endpoint in the build method.

Supported keys:

  • aws_endpoint_url_s3


Token

Token to use for requests (passed to underlying provider)

See [AmazonS3Builder::with_token] for details.

Supported keys:

  • aws_session_token
  • aws_token
  • session_token
  • token


ImdsV1Fallback

Fall back to ImdsV1

See [AmazonS3Builder::with_imdsv1_fallback] for details.

Supported keys:

  • aws_imdsv1_fallback
  • imdsv1_fallback


VirtualHostedStyleRequest

If virtual hosted style request has to be used

See [AmazonS3Builder::with_virtual_hosted_style_request] for details.

Supported keys:

  • aws_virtual_hosted_style_request
  • virtual_hosted_style_request


UnsignedPayload

Avoid computing payload checksum when calculating signature.

See [AmazonS3Builder::with_unsigned_payload] for details.

Supported keys:

  • aws_unsigned_payload
  • unsigned_payload


Checksum

Set the checksum algorithm for this client

See [AmazonS3Builder::with_checksum_algorithm] for details.



MetadataEndpoint

Set the instance metadata endpoint

See [AmazonS3Builder::with_metadata_endpoint] for details.

Supported keys:

  • aws_metadata_endpoint
  • metadata_endpoint


ContainerCredentialsRelativeUri

Set the container credentials relative URI when used in ECS

https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html

Supported keys:

  • aws_container_credentials_relative_uri
  • container_credentials_relative_uri

Example: /v2/credentials/abc123



ContainerCredentialsFullUri

Set the container credentials full URI when used in EKS

https://docs.aws.amazon.com/sdkref/latest/guide/feature-container-credentials.html

Supported keys:

  • aws_container_credentials_full_uri
  • container_credentials_full_uri

Example: http://169.254.170.2/v2/credentials/abc123



ContainerAuthorizationTokenFile

Set the authorization token in plain text when used in EKS to authenticate with ContainerCredentialsFullUri

https://docs.aws.amazon.com/sdkref/latest/guide/feature-container-credentials.html

Supported keys:

  • aws_container_authorization_token_file
  • container_authorization_token_file

Example: /var/run/secrets/eks.amazonaws.com/serviceaccount/token



WebIdentityTokenFile

Web identity token file path for AssumeRoleWithWebIdentity

Supported keys:

  • aws_web_identity_token_file
  • web_identity_token_file

Example: /var/run/secrets/eks.amazonaws.com/serviceaccount/token



RoleArn

Role ARN to assume when using web identity token

Supported keys:

  • aws_role_arn
  • role_arn

Example: arn:aws:iam::123456789012:role/MyWebIdentityRole



RoleSessionName

Session name for web identity role assumption

Supported keys:

  • aws_role_session_name
  • role_session_name


StsEndpoint

Custom STS endpoint for web identity token exchange

Defaults to https://sts.{region}.amazonaws.com

Supported keys:

  • aws_endpoint_url_sts
  • endpoint_url_sts


CopyIfNotExists

Configure how to provide copy_if_not_exists

See [S3CopyIfNotExists] for details.

Supported keys:

  • aws_copy_if_not_exists
  • copy_if_not_exists


ConditionalPut

Configure how to provide conditional put operations

See [S3ConditionalPut] for details.

Supported keys:

  • aws_conditional_put
  • conditional_put


SkipSignature

Skip signing request

See [AmazonS3Builder::with_skip_signature] for details.

Supported keys:

  • aws_skip_signature
  • skip_signature


DisableTagging

Disable tagging objects

If set to true will ignore any tags provided to put_opts. This can be desirable if not supported by the backing store

Supported keys:

  • aws_disable_tagging
  • disable_tagging


S3Express

Enable Support for S3 Express One Zone

Supported keys:

  • aws_s3_express
  • s3_express


RequestPayer

Enable Support for S3 Requester Pays

Supported keys:

  • aws_request_payer
  • request_payer


Client(ClientConfigKey)

Client options



Encryption(S3EncryptionConfigKey)

Encryption options