pub struct CloudDirectionalRateLimitConfig {
pub init_rate: Option<u64>,
pub floor_rate: Option<u64>,
pub ceiling_rate: Option<u64>,
}Expand description
Rate-limit config publicly exposed through storage_options.
Fields
init_rate: Option<u64>floor_rate: Option<u64>ceiling_rate: Option<u64>Trait Implementations
Sourceimpl Clone for CloudDirectionalRateLimitConfig
impl Clone for CloudDirectionalRateLimitConfig
Sourcefn clone(&self) -> CloudDirectionalRateLimitConfig
fn clone(&self) -> CloudDirectionalRateLimitConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CloudDirectionalRateLimitConfig
Sourceimpl Default for CloudDirectionalRateLimitConfig
impl Default for CloudDirectionalRateLimitConfig
Sourcefn default() -> CloudDirectionalRateLimitConfig
fn default() -> CloudDirectionalRateLimitConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CloudDirectionalRateLimitConfig
Available on crate feature serde only.
impl<'de> Deserialize<'de> for CloudDirectionalRateLimitConfig
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CloudDirectionalRateLimitConfig
Sourceimpl JsonSchema for CloudDirectionalRateLimitConfig
Available on crate feature dsl-schema only.
impl JsonSchema for CloudDirectionalRateLimitConfig
Available on crate feature
dsl-schema only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CloudDirectionalRateLimitConfig
Available on crate feature serde only.
impl Serialize for CloudDirectionalRateLimitConfig
Available on crate feature
serde only.impl StructuralPartialEq for CloudDirectionalRateLimitConfig