pub struct CloudRetryConfig {
pub max_retries: Option<usize>,
pub retry_timeout: Option<Duration>,
pub retry_init_backoff: Option<Duration>,
pub retry_max_backoff: Option<Duration>,
pub retry_base_multiplier: Option<TotalOrdWrap<f64>>,
}Fields
max_retries: Option<usize>retry_timeout: Option<Duration>retry_init_backoff: Option<Duration>retry_max_backoff: Option<Duration>retry_base_multiplier: Option<TotalOrdWrap<f64>>Trait Implementations
Sourceimpl Clone for CloudRetryConfig
impl Clone for CloudRetryConfig
Sourcefn clone(&self) -> CloudRetryConfig
fn clone(&self) -> CloudRetryConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CloudRetryConfig
Sourceimpl Debug for CloudRetryConfig
impl Debug for CloudRetryConfig
Sourceimpl Default for CloudRetryConfig
impl Default for CloudRetryConfig
Sourcefn default() -> CloudRetryConfig
fn default() -> CloudRetryConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CloudRetryConfig
Available on crate feature serde only.
impl<'de> Deserialize<'de> for CloudRetryConfig
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CloudRetryConfig
Sourceimpl From<CloudRetryConfig> for RetryConfig
Available on crate features aws or azure or gcp only.
impl From<CloudRetryConfig> for RetryConfig
Available on crate features
aws or azure or gcp only.Sourcefn from(value: CloudRetryConfig) -> Self
fn from(value: CloudRetryConfig) -> Self
Converts to this type from the input type.
Sourceimpl Hash for CloudRetryConfig
impl Hash for CloudRetryConfig
Sourceimpl JsonSchema for CloudRetryConfig
Available on crate feature dsl-schema only.
impl JsonSchema for CloudRetryConfig
Available on crate feature
dsl-schema only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CloudRetryConfig
impl PartialEq for CloudRetryConfig
Sourceimpl Serialize for CloudRetryConfig
Available on crate feature serde only.
impl Serialize for CloudRetryConfig
Available on crate feature
serde only.impl StructuralPartialEq for CloudRetryConfig