pub enum QuoteStyle {
Necessary,
Always,
NonNumeric,
Never,
}Available on crate features
csv or json only.Expand description
Quote style indicating when to insert quotes around a field.
Variants
Necessary
Quote fields only when necessary.
Quotes are necessary when fields contain a quote, separator or record terminator. Quotes are also necessary when writing an empty record (which is indistinguishable from arecord with one empty field). This is the default.
Always
Quote every field. Always.
NonNumeric
Quote non-numeric fields.
When writing a field that does not parse as a valid float or integer, quotes will be used even if they aren’t strictly necessary.
Never
Never quote any fields, even if it would produce invalid CSV data.