pub enum ExternalCompression {
Uncompressed,
Gzip {
level: Option<u32>,
},
Zstd {
level: Option<u32>,
},
}Expand description
Compression options for file that are expressed externally like CSV and NDJSON. Externally does not mean by an external tool, more that it doesn’t happen internally like it does for Parquet and IPC.
Compared to other formats like IPC and Parquet, compression is external.
Variants
Implementations