IpcReader

Struct IpcReader 

pub struct IpcReader<R: MmapBytesReader> { /* private fields */ }
Available on (crate features ipc or ipc_streaming) and crate feature ipc only.
Read Arrows IPC format into a DataFrame

Example

use polars_core::prelude::*;
use std::fs::File;
use polars_io::ipc::IpcReader;
use polars_io::SerReader;

fn example() -> PolarsResult<DataFrame> {
    let file = File::open("file.ipc").expect("file not found");

    IpcReader::new(file)
        .finish()
}

Implementations

Source

impl<R: MmapBytesReader> IpcReader<R>

pub fn schema(&mut self) -> PolarsResult<ArrowSchemaRef>

Get arrow schema of the Ipc File.

pub fn custom_metadata(&mut self) -> PolarsResult<Option<Arc<Metadata>>>

Get schema-level custom metadata of the Ipc file

pub fn with_n_rows(self, num_rows: Option<usize>) -> Self

Stop reading when n rows are read.

pub fn with_columns(self, columns: Option<Vec<String>>) -> Self

Columns to select/ project

pub fn with_hive_partition_columns(self, columns: Option<Vec<Series>>) -> Self

pub fn with_include_file_path( self, include_file_path: Option<(PlSmallStr, PlRefStr)>, ) -> Self

pub fn with_row_index(self, row_index: Option<RowIndex>) -> Self

Add a row index column.

pub fn with_projection(self, projection: Option<Vec<usize>>) -> Self

Set the reader’s column projection. This counts from 0, meaning that vec![0, 4] would select the 1st and 5th column.

pub unsafe fn memory_mapped(self, path_buf: Option<PathBuf>) -> Self

Set if the file is to be memory_mapped. Only works with uncompressed files. The file name must be passed to register the memory mapped file.

Safety

The users guarantees that the arrow data in the given path is valid and remains valid throughout memory mapping.

pub fn finish_with_scan_ops( self, predicate: Option<Arc<dyn PhysicalIoExpr>>, verbose: bool, ) -> PolarsResult<DataFrame>

Available on crate feature lazy only.