pub struct IpcScanOptions {
pub record_batch_statistics: bool,
pub checked: UnsafeBool,
}Available on crate feature
ipc and (crate features ipc_streaming or ipc) only.Fields
record_batch_statistics: boolRead StatisticsFlags from the record batch custom metadata.
checked: UnsafeBoolTrait Implementations
Sourceimpl Clone for IpcScanOptions
impl Clone for IpcScanOptions
Sourcefn clone(&self) -> IpcScanOptions
fn clone(&self) -> IpcScanOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IpcScanOptions
impl Debug for IpcScanOptions
Sourceimpl Default for IpcScanOptions
impl Default for IpcScanOptions
Sourceimpl<'de> Deserialize<'de> for IpcScanOptions
Available on crate feature serde only.
impl<'de> Deserialize<'de> for IpcScanOptions
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for IpcScanOptions
impl Hash for IpcScanOptions
Sourceimpl JsonSchema for IpcScanOptions
Available on crate feature dsl-schema only.
impl JsonSchema for IpcScanOptions
Available on crate feature
dsl-schema only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for IpcScanOptions
impl PartialEq for IpcScanOptions
Sourceimpl Serialize for IpcScanOptions
Available on crate feature serde only.
impl Serialize for IpcScanOptions
Available on crate feature
serde only.impl StructuralPartialEq for IpcScanOptions