pub struct NDJsonWriterOptions {
pub compression: ExternalCompression,
pub check_extension: bool,
}Available on crate feature
json only.Fields
compression: ExternalCompressioncheck_extension: boolTrait Implementations
Sourceimpl Clone for NDJsonWriterOptions
impl Clone for NDJsonWriterOptions
Sourcefn clone(&self) -> NDJsonWriterOptions
fn clone(&self) -> NDJsonWriterOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NDJsonWriterOptions
Sourceimpl Debug for NDJsonWriterOptions
impl Debug for NDJsonWriterOptions
Sourceimpl Default for NDJsonWriterOptions
impl Default for NDJsonWriterOptions
Sourcefn default() -> NDJsonWriterOptions
fn default() -> NDJsonWriterOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for NDJsonWriterOptions
Available on crate feature serde only.
impl<'de> Deserialize<'de> for NDJsonWriterOptions
Available on crate feature
serde only.Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NDJsonWriterOptions
Sourceimpl Hash for NDJsonWriterOptions
impl Hash for NDJsonWriterOptions
Sourceimpl JsonSchema for NDJsonWriterOptions
Available on crate feature dsl-schema only.
impl JsonSchema for NDJsonWriterOptions
Available on crate feature
dsl-schema only.Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NDJsonWriterOptions
impl PartialEq for NDJsonWriterOptions
Sourceimpl Serialize for NDJsonWriterOptions
Available on crate feature serde only.
impl Serialize for NDJsonWriterOptions
Available on crate feature
serde only.impl StructuralPartialEq for NDJsonWriterOptions