ensure_matching_dtypes_if_found

Function ensure_matching_dtypes_if_found 

pub fn ensure_matching_dtypes_if_found(
    schema: &ArrowSchema,
    current_schema: &ArrowSchema,
) -> PolarsResult<()>
Available on crate feature parquet only.
Utility to ensure the dtype of the column in current_schema matches the dtype in schema if that column exists in schema.