cast_bound

Function cast_bound 

pub fn cast_bound(bound: &Scalar, dtype: &DataType) -> Option<Scalar>
A range bound as dtype, or None when it does not survive the cast, in which case it bounds nothing.