pub struct StagedScanIOPredicate {
pub column_predicates: Arc<PlIndexMap<PlSmallStr, ColumnPredicate>>,
pub rest: Option<Arc<dyn PhysicalIoExpr>>,
}Expand description
The row predicate split into the conjuncts that read a single column and the rest.
Fields
column_predicates: Arc<PlIndexMap<PlSmallStr, ColumnPredicate>>rest: Option<Arc<dyn PhysicalIoExpr>>The conjuncts that read no or several columns, conjoined.